==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/th_TH.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "กิจกรรม",
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Your settings have been updated." : "การตั้งค่าของคุณได้รับการปรับปรุง",
    "Mail" : "จดหมาย",
    "Stream" : "สตรีม",
    "Activities" : "กิจกรร",
    "Error loading activities" : "เกิดข้อผิดพลาดขณะโหลดกิจกรรม",
    "No activities" : "ไม่มีกิจกรรม",
    ", " : "หรือ",
    "{parameterList} and {lastParameter}" : "{parameterList} และ {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} และ {linkStart} %n มากกว่า {linkEnd}"],
    "in {directory}" : "ใน {directory}",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์เพิ่มเติม เช่นการเปลี่ยนแปลงและการแชร์",
    "There are no events for this filter" : "ไม่มีกิจกรรมสำหรับตัวกรองนี้",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "\"remote user\"" : "\"ผู้ใช้ระยะไกล\"",
    "Activity notification" : "การแจ้งเตือนกิจกรรม",
    "All Activities" : "กิจกรรมทั้งหมด",
    "Activities by you" : "กิจกรรมของคุณ",
    "Activities by others" : "กิจกรรมของคนอื่นๆ",
    "%s and %s" : "%s และ %s",
    "Hello %s," : "สวัสดี %s",
    "You are receiving this email because the following things happened at %s" : "หากคุณได้รับอีเมลนี้เป็นเพราะว่ามีบางอย่างผิดปกติที่ %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* และ %n ฯลฯ"],
    "List your own actions in the stream" : "รายการสิ่งที่คุณทำในสตรีม",
    "Notify about your own actions via email" : "แจ้งเตือนเกี่ยวกับสิ่งที่คุณทำผ่านทางอีเมล",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send emails:" : "ส่งอีเมล:",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รายวัน",
    "Weekly" : "รายสัปดาห์",
    "Activity feed" : "ฟีดกิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "No more events to load" : "ไม่มีการโหลดกิจกรรมเพิ่มเติม",
    "Files" : "ไฟล์"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/th_TH.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "กิจกรรม",
    "Activities" : "กิจกรรม",
    "Error loading activities" : "เกิดข้อผิดพลาดขณะโหลดกิจกรรม",
    "No activities" : "ยังไม่มีกิจกรรม",
    "Load more activities" : "โหลดกิจกรรมอื่นๆ",
    ", " : "หรือ",
    "{parameterList} and {lastParameter}" : "{parameterList} และ {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} และ {linkStart} %n มากกว่า {linkEnd}"],
    "in {directory}" : "ใน {directory}",
    "This stream will show events like additions, changes & shares" : "สตรีมนี้จะแสดงเหตุการณ์เพิ่มเติม เช่นการเปลี่ยนแปลงและการแชร์",
    "There are no events for this filter" : "ไม่มีกิจกรรมสำหรับตัวกรองนี้",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "Personal activity feed for %s" : "ฟีดกิจกรรมส่วนตัวสำหรับ %s",
    "Your feed URL is invalid" : "ฟีด URL ของคุณไม่ถูกต้อง",
    "Your settings have been updated." : "อัพเดทการตั้งค่าเรียบร้อยแล้ว",
    "Mail" : "จดหมาย",
    "Stream" : "สตรีม",
    "\"remote user\"" : "\"ผู้ใช้โดยการรีโมท\"",
    "Activity notification" : "การแจ้งเตือนกิจกรรม",
    "All Activities" : "กิจกรรมทั้งหมด",
    "Activities by you" : "กิจกรรมของคุณ",
    "Activities by others" : "กิจกรรมของคนอื่นๆ",
    "%s and %s" : "%s และ %s",
    "Hello %s," : "สวัสดี %s",
    "You are receiving this email because the following things happened at %s" : "หากคุณได้รับอีเมลนี้เป็นเพราะว่ามีบางอย่างผิดปกติที่ %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* และ %n ฯลฯ"],
    "List your own file actions in the stream" : "รายชื่อไฟล์การกระทำของคุณในสตรีม",
    "Notify about your own actions via email" : "แจ้งเตือนเกี่ยวกับสิ่งที่คุณทำผ่านทางอีเมล",
    "You need to set up your email address before you can receive notification emails." : "คุณจะได้รับอีเมลแจ้งเตือนหลังจากที่คุณตั้งค่าที่อยู่อีเมลของคุณ",
    "Send emails:" : "ส่งอีเมล:",
    "Hourly" : "รายชั่วโมง",
    "Daily" : "รุ่นรายวัน",
    "Weekly" : "รายสัปดาห์",
    "Activity feed" : "ฟีดกิจกรรม",
    "Enable RSS feed" : "เปิดใช้งานฟีด RSS",
    "No activity yet" : "ยังไม่มีกิจกรรม",
    "No more events to load" : "ไม่มีการโหลดกิจกรรมเพิ่มเติม",
    "Files" : "ไฟล์"
},
"nplurals=1; plural=0;");
